@@ -1,11 +1,18 @@
 """Navigation module."""
 
+from __future__ import unicode_literals
+
 __all__ = ["swap_to", "swap_windows"]
 
+from typing import List, Optional
+
 import system.nav
 
+from incendium.types import DictStringAny, String
+
 
 def _get_full_path(from_path, to_path):
+    # type: (String, String) -> String
     """Return the full path of the window to swap to.
 
     The path will be relative to the path of the window to swap from.
@@ -16,7 +23,7 @@ def _get_full_path(from_path, to_path):
             to.
 
     Returns:
-        str: The full path of the window to swap to.
+        The full path of the window to swap to.
     """
     current_directory = "."
     parent_directory = ".."
@@ -31,7 +38,7 @@ def _get_full_path(from_path, to_path):
     elif _to[0] == current_directory:
         path_parts = _from[:-1] + _to[1:]
 
-    full_path = []
+    full_path = []  # type: List[String]
     for path_part in path_parts:
         if path_part == parent_directory and full_path:
             full_path = full_path[:-1]
@@ -42,35 +49,34 @@ def _get_full_path(from_path, to_path):
 
 
 def swap_to(path, params=None):
+    # type: (String, Optional[DictStringAny]) -> None
     """Perform a window swap.
 
     This will swap from the current main screen window to the window
     specified.
 
     Args:
-        path (str): The full path or relative path of the window to
-            swap to.
-        params (dict): A dictionary of parameters to pass into the
-            window. The keys in the dictionary must match dynamic
-            property names on the target window's root container. The
-            values for each key will be used to set those properties.
-            Optional.
+        path: The full path or relative path of the window to swap to.
+        params: A dictionary of parameters to pass into the window. The
+            keys in the dictionary must match dynamic property names on
+            the target window's root container. The values for each key
+            will be used to set those properties. Optional.
     """
     swap_windows(system.nav.getCurrentWindow(), path, params)
 
 
 def swap_windows(from_path, to_path, params=None):
+    # type: (String, String, Optional[DictStringAny]) -> None
     """Perform a window swap.
 
     Args:
-        from_path (str): The full path of the window to swap from.
-        to_path (str): The full path or relative path of the window to
-            swap to.
-        params (dict): A dictionary of parameters to pass into the
-            window. The keys in the dictionary must match dynamic
-            property names on the target window's root container. The
-            values for each key will be used to set those properties.
-            Optional.
+        from_path: The full path of the window to swap from.
+        to_path: The full path or relative path of the window to swap
+            to.
+        params: A dictionary of parameters to pass into the window. The
+            keys in the dictionary must match dynamic property names on
+            the target window's root container. The values for each key
+            will be used to set those properties. Optional.
     """
     _to_path = _get_full_path(from_path, to_path)
     if _to_path != from_path:
